@@ -14,7 +14,7 @@ use Marpa::R2;
 
 # AUTHORITY
 
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 
 our $DATA = do { local $/; <DATA>; };
@@ -38,6 +38,8 @@ has port          => (is => 'ro', isa => Str|Undef,     default => undef,      w
 has relative_part => (is => 'ro', isa => Str|Undef,     default => undef,      writer => '_set_relative_part');
 has ip_literal    => (is => 'ro', isa => Str|Undef,     default => undef,      writer => '_set_ip_literal');
 has zoneid        => (is => 'ro', isa => Str|Undef,     default => undef,      writer => '_set_zoneid' );
+has ipv4address   => (is => 'ro', isa => Str|Undef,     default => undef,      writer => '_set_ipv4address');
+has reg_name      => (is => 'ro', isa => Str|Undef,     default => undef,      writer => '_set_reg_name');
 
 sub BUILDARGS {
   my ($class, @args) = @_;
@@ -84,6 +86,8 @@ sub _marpa_port          { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return
 sub _marpa_relative_part { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return $self->_set_relative_part ($self->_marpa_concat(@_)); }
 sub _marpa_ip_literal    { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return $self->_set_ip_literal    ($self->_marpa_concat(@_)); }
 sub _marpa_zoneid        { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return $self->_set_zoneid        ($self->_marpa_concat(@_)); }
+sub _marpa_ipv4address   { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return $self->_set_ipv4address   ($self->_marpa_concat(@_)); }
+sub _marpa_reg_name      { shift; my $self = $MarpaX::RFC::RFC3986::SELF; return $self->_set_reg_name      ($self->_marpa_concat(@_)); }
 
 1;
 
@@ -97,7 +101,7 @@ MarpaX::RFC::RFC3986 - Uniform Resource Identifier (URI): Generic Syntax - Marpa
 
 =head1 VERSION
 
-version 0.001
+version 0.002
 
 =head1 SYNOPSIS
 
@@ -137,7 +141,7 @@ An absolute URI has the following structure:
 
          URI = scheme ":" hier-part [ "?" query ] [ "#" fragment ]
 
-while a relative URI is splitted into:
+while a relative URI is split into:
 
          relative-ref  = relative-part [ "?" query ] [ "#" fragment ]
 
@@ -145,7 +149,11 @@ Back to the overall structure, the authority is:
 
          authority   = [ userinfo "@" ] host [ ":" port ]
 
-where the host can be an IP-literal with Zone information:
+where the host can be an IP-literal with Zone information, and IPV4 address or a registered name:
+
+         host = IP-literal / IPv4address / reg-name
+
+The Zone Identifier is an extension to original RFC3986, and is defined in RFC6874:
 
          IP-literal = "[" ( IPv6address / IPv6addrz / IPvFuture  ) "]"
 
@@ -155,73 +163,81 @@ where the host can be an IP-literal with Zone information:
 
 =head1 CLASS METHODS
 
-=head2 MarpaX::RFC::RFC3986->new(@options) --> InstanceOf['MarpaX::RFC::RFC3986']
+=head2 MarpaX::RFC::RFC3986->new(@options --> InstanceOf['MarpaX::RFC::RFC3986'])
 
 Instantiate a new object. Usage is either C<MarpaX::RFC::RFC3986-E<gt>new(value =E<gt> $url)> or C<MarpaX::RFC::RFC3986-E<gt>new($url)>. This method will croak if the the C<$url> parameter cannot coerce to a string nor is a valid URI. The variable C<$self> is used below to refer to this object instance.
 
-=head2 MarpaX::RFC::RFC3986->grammar --> InstanceOf['Marpa::R2::Scanless::G']
+=head2 MarpaX::RFC::RFC3986->grammar( --> InstanceOf['Marpa::R2::Scanless::G'])
 
 A Marpa::R2::Scanless::G instance, hosting the computed grammar. This is a class variable, i.e. works also with C<$self>.
 
-=head2 MarpaX::RFC::RFC3986->bnf --> Str
+=head2 MarpaX::RFC::RFC3986->bnf( --> Str)
 
 The BNF grammar used to parse an URI. This is a class variable, i.e. works also with C<$self>.
 
 =head1 OBJECT METHODS
 
-=head2 $self->value --> Str
+=head2 $self->value( --> Str)
 
 The variable given in input to C<new()>.
 
-=head2 $self->scheme --> Str|Undef
+=head2 $self->scheme( --> Str|Undef)
 
 The URI scheme. Can be undefined.
 
-=head2 $self->authority --> Str|Undef
+=head2 $self->authority( --> Str|Undef)
 
 The URI authority. Can be undefined.
 
-=head2 $self->path --> Str
+=head2 $self->path( --> Str)
 
 The URI path. Note that an URI always have a path, although it can be empty.
 
-=head2 $self->query --> Str|Undef
+=head2 $self->query( --> Str|Undef)
 
 The URI query. Can be undefined.
 
-=head2 $self->fragment --> Str|Undef
+=head2 $self->fragment( --> Str|Undef)
 
 The URI fragment. Can be undefined.
 
-=head2 $self->hier_part --> Str|Undef
+=head2 $self->hier_part( --> Str|Undef)
 
 The URI hier part. Can be undefined.
 
-=head2 $self->userinfo --> Str|Undef
+=head2 $self->userinfo( --> Str|Undef)
 
 The URI userinfo. Can be undefined.
 
-=head2 $self->host --> Str|Undef
+=head2 $self->host( --> Str|Undef)
 
 The URI host. Can be undefined.
 
-=head2 $self->port --> Str|Undef
+=head2 $self->port( --> Str|Undef)
 
 The URI port. Can be undefined.
 
-=head2 $self->relative_part --> Str|Undef
+=head2 $self->relative_part( --> Str|Undef)
 
 The URI relative part. Can be undefined.
 
-=head2 $self->ip_literal --> Str|Undef
+=head2 $self->ip_literal( --> Str|Undef)
 
 The URI IP literal. Can be undefined.
 
-=head2 $self->zoneid --> Str|Undef
+=head2 $self->zoneid( --> Str|Undef)
 
 The URI IP's zone id. Can be undefined.
 
-=head2 $self->is_absolute --> Bool
+=head2 $self->ipv4address( --> Str|Undef)
+
+The URI IP Version 4 address. Can be undefined.
+
+=head2 $self->reg_name( --> Str|Undef)
+
+The URI registered name. Can be undefined.
+
+=head2 $self->is_absolute( --> Bool)
 
 Returns a true value if the URI is absolute, false otherwise.
 
@@ -388,7 +404,7 @@ inaccessible is ok by default
 <ls32>          ::= <h16> ':' <h16>
                   | <IPv4address>
 
-IPv4address     ::= <dec octet> '.' <dec octet> '.' <dec octet> '.' <dec octet>
+IPv4address     ::= <dec octet> '.' <dec octet> '.' <dec octet> '.' <dec octet> action => MarpaX::RFC::RFC3986::_marpa_ipv4address
 
 <dec octet>     ::=                      DIGIT # 0-9
                   |      [\x{31}-\x{39}] DIGIT # 10-99
@@ -397,7 +413,7 @@ IPv4address     ::= <dec octet> '.' <dec octet> '.' <dec octet> '.' <dec octet>
                   | '25' [\x{30}-\x{35}]       # 250-255
 
 <reg name unit> ::= <unreserved> | <pct encoded> | <sub delims>
-<reg name>      ::= <reg name unit>*
+<reg name>      ::= <reg name unit>*                                 action => MarpaX::RFC::RFC3986::_marpa_reg_name
 
 <path>          ::= <path abempty>    # begins with "/" or is empty
                   | <path absolute>   # begins with "/" but not "//"
